#!/usr/bin/python3
import os
import sys
import subprocess

armv8 = [
    'CFG_ARM64_core=y',
    'CFG_TEE_BENCHMARK=n',
    'CFG_TEE_CORE_LOG_LEVEL=3',
    'CFG_CORE_ARM64_PA_BITS=48',
]

qemu = [
    'PLATFORM=vexpress-qemu_armv8a',
    'CFG_ARM_GICV3=n',
]

stmm = [
    'CFG_CORE_HEAP_SIZE=524288',
    'CFG_CORE_DYN_SHM=y',
    'CFG_STMM_PATH=/usr/share/edk2/aarch64/BL32_AP_MM.fd',
    'CFG_RPMB_FS=y',
    'CFG_RPMB_FS_DEV_ID=0',
    'CFG_RPMB_WRITE_KEY=y',
    'CFG_RPMB_TESTKEY=y',
    'CFG_REE_FS=n',
]

ffa = [
    'CFG_CORE_FFA=y',
]

def do_build(dest, options):
    cmdline = [
        'make',
        'CROSS_COMPILE=aarch64-linux-gnu-',
        'CROSS_COMPILE32=arm-linux-gnu-',
        'DEBUG=1',
    ]
    cmdline += options
    cmdline += [ f'O={dest}', ]
    print(cmdline, flush = True)
    subprocess.run(cmdline, check = True)

def main():
    do_build('out-qemu-bare', armv8 + qemu)
    do_build('out-qemu-stmm', armv8 + qemu + stmm)
    do_build('out-qemu-ffa',  armv8 + qemu + ffa)

if __name__ == '__main__':
    sys.exit(main())
